# Updated 2021 November 08

#### CODE PREAMBLE AND DESCRIPTION ####

## Code preamble: prepare workspace and load R packages

rm(list = ls())     # Clear workspace
library(data.table) # R package for using data.tables as augmented data.frames
library(fixest)     # R package for fixed effects estimation
library(ggplot2)    # R package for generating graphs
library(usmap)      # R package for generating maps
library(grid)       # R package for combining sub-figures
library(gridExtra)  # R package for combining sub-figures
library(cowplot)    # R package for combining sub-figures
datadir = "~/Dropbox/Shared/SchoolsCovid/data" # SET THIS: top-level data directory
figuresdir = "~/Dropbox/Shared/SchoolsCovid/figures" # SET THIS: directory in which to save figures
setwd(datadir)

## List of figures:
#   1) Map of counties with three groups by teaching method
#  2A) Event study coefficients plot for hybrid teaching v. remote in panel fixed effects model: daily per-capita COVID deaths
#  2B) Event study coefficients plot for campus teaching v. remote in panel fixed effects model: daily per-capita COVID deaths
#   3) Line graph of employment per thousand population with three groups by teaching method
#  B1) Line graph of share of counties with school started for 2020-21AY with three groups by teaching method
#  B2) Line graph of community mobility measures with three groups by teaching method
# B3A) Line graph of 7-day moving average daily new COVID-19 cases per million population with three groups by teaching method
# B3B) Line graph of 7-day moving average daily COVID-19 deaths per million population with three groups by teaching method
#

## Data and programming notes:
#
# 1. Running this code requires about 4 GB of RAM.
#
# 2. Uses data prepared in code step "1_Compile_Data.R"
#

#### LOAD AND PREPARE DATA ####

setwd(datadir)

# Read in data in county panel

county.panel <- fread("county_panel.csv")

# Define COVID cases per million population, deaths per million population, and employment per thousand population

county.panel[, cumulative_cases_per1m := cumulative_cases / (population / 1000000)]
county.panel[, cumulative_deaths_per1m := cumulative_deaths / (population / 1000000)]
county.panel[, daily_cases_per1m := daily_cases / (population / 1000000)]
county.panel[, daily_deaths_per1m := daily_deaths / (population / 1000000)]
county.panel[, employment_per1k := employment / (population / 1000)]

setwd(figuresdir)

#### (1) MAP OF COUNTIES WITH 3 GROUPS BY TEACHING METHOD ####

gg.county.map.data <- county.panel[date == "2020-03-01", .(fips, classroom)]

plot_usmap("counties", data = gg.county.map.data, value = "classroom", size = 0.025) + 
  scale_fill_manual(name = "Teaching method", values = c("#E66100", "#A95AA1", "#85C0F9"), na.translate = FALSE) +
  theme(legend.position = c(0.88, 0.22), legend.background = element_rect(color = "black", fill = "white"), text = element_text(size = 14))

ggsave(file.path(figuresdir, "Figure01-counties-map-school-policy.png"), width = 10, height = 6, units = "in", dpi = 200)
ggsave(file.path(figuresdir, "Figure01-counties-map-school-policy.pdf"), width = 10, height = 6, units = "in", dpi = 200)
rm(gg.county.map.data)

#### (2A) EVENT STUDY COEFFICIENTS PLOT FOR CAMPUS COMPARED TO REMOTE TEACHING: DAILY COVID DEATHS PER MILLION POPULATION ####

# Daily balanced panel of counties starting with March 1st of 2020

event.study.panel <- copy(county.panel[date >= "2020-03-01", .(fips, date, state_name, classroom, open_date, daily_deaths_per1m)])
event.study.panel[, weeks_to_open := floor(as.integer(difftime(date, open_date, units = "days")) / 7)]
event.study.panel <- event.study.panel[classroom %in% c("Campus", "Remote")]

# Define event study weekly indicator terms for regression

invisible(lapply(-20:-1, function(d) {
  event.study.panel[, paste0("inperson_pre_", sprintf("%02d", -1*d)) := ifelse(classroom == "Campus" & weeks_to_open == d, 1, 0)]
}))
invisible(lapply(1:30, function(d) {
  event.study.panel[, paste0("inperson_post_", sprintf("%02d", d)) := ifelse(classroom == "Campus" & weeks_to_open == d, 1, 0)]
})) 
event.study.panel[, inperson_pre_by_more := ifelse(classroom == "Campus" & weeks_to_open < -20, 1, 0)]
event.study.panel[, inperson_post_by_more := ifelse(classroom == "Campus" & weeks_to_open > 30, 1, 0)]

# Event study diff-in-diff regression

mod.event.study.weekly <- summary(feols(daily_deaths_per1m ~ 
                                          inperson_pre_20 + inperson_pre_19 + inperson_pre_18 + inperson_pre_17 + inperson_pre_16 + 
                                          inperson_pre_15 + inperson_pre_14 + inperson_pre_13 + inperson_pre_12 + inperson_pre_11 + 
                                          inperson_pre_10 + inperson_pre_09 + inperson_pre_08 + inperson_pre_07 + inperson_pre_06 + 
                                          inperson_pre_05 + inperson_pre_04 + inperson_pre_03 + inperson_pre_02 + inperson_pre_01 + 
                                          inperson_post_01 + inperson_post_02 + inperson_post_03 + inperson_post_04 + inperson_post_05 + 
                                          inperson_post_06 + inperson_post_07 + inperson_post_08 + inperson_post_09 + inperson_post_10 + 
                                          inperson_post_11 + inperson_post_12 + inperson_post_13 + inperson_post_14 + inperson_post_15 +
                                          inperson_post_16 + inperson_post_17 + inperson_post_18 + inperson_post_19 + inperson_post_20 + 
                                          inperson_post_21 + inperson_post_22 + inperson_post_23 + inperson_post_24 + inperson_post_25 +
                                          inperson_post_26 + inperson_post_27 + inperson_post_28 + inperson_post_29 + inperson_post_30 + 
                                          inperson_pre_by_more + inperson_post_by_more
                                        | fips + date, data = event.study.panel), 
                                  cluster = ~ state_name + weeks_to_open)

# Combine coefficients into graph data and determine 95 percent confidence interval for each coefficient

gg.event.study.weekly <- data.table(weeks_to_open = c(-20:-1, 1:30))
gg.event.study.weekly[, coefname := names(coef(mod.event.study.weekly))[1:length(gg.event.study.weekly$weeks_to_open)]]
gg.event.study.weekly[, coef := coef(mod.event.study.weekly)[1:length(gg.event.study.weekly$weeks_to_open)]]
gg.event.study.weekly[, se := se(mod.event.study.weekly)[1:length(gg.event.study.weekly$weeks_to_open)]]
gg.event.study.weekly <- rbind(gg.event.study.weekly, data.table(weeks_to_open = 0, coefname = "inperson_open_week", coef = 0, se = 0))
setkey(gg.event.study.weekly, weeks_to_open)
gg.event.study.weekly[, uci95 := coef + 1.96 * se][, lci95 := coef - 1.96 * se]

# Plot and save graph

ggplot(gg.event.study.weekly, aes(x = weeks_to_open)) +
  geom_hline(yintercept = 0, color = "black") + 
  geom_vline(xintercept = 0, color = "black", linetype = "dashed") +
  annotate("segment", x = -3.5, xend = -0.25, y = 11, yend = 11, arrow = arrow(length = unit(0.25, "cm")), color = "black", size = 0.5) +
  annotate("label", x = -5, y = 11, label = "Start of the\n2020-2021\nschool year", color = "black", size = 4) +
  geom_errorbar(aes(ymin = lci95, ymax = uci95), color = "grey70", width = .1) + 
  geom_point(aes(y = coef), shape = 19, size = 4, color = "#E66100") +
  scale_x_continuous(name = "Weeks before (-) or after (+) county started teaching 2020-2021 school year", 
                     limits = c(-20.5, 30.5), breaks = c(-20, -10, 0, 10, 20, 30)) +
  scale_y_continuous(name = "Estimated coefficient: Daily deaths per million pop.", breaks = c(-5, 0, 5, 10, 15), limits = c(-5, 15)) +
  theme_bw() + theme(panel.grid = element_blank(), text = element_text(size = 14))

ggsave(file.path(figuresdir, "Figure02A-event-study-daily-covid-deaths-per-million-campus.pdf"), width = 10, height = 5, units = "in", dpi = 200)
rm(event.study.panel, mod.event.study.weekly, gg.event.study.weekly)

#### (2B) EVENT STUDY COEFFICIENTS PLOT FOR HYBRID COMPARED TO REMOTE TEACHING: DAILY COVID DEATHS PER MILLION POPULATION ####

# Daily balanced panel of counties starting with March 1st of 2020

event.study.panel <- copy(county.panel[date >= "2020-03-01", .(fips, date, state_name, classroom, open_date, daily_deaths_per1m)])
event.study.panel[, weeks_to_open := floor(as.integer(difftime(date, open_date, units = "days")) / 7)]
event.study.panel <- event.study.panel[classroom %in% c("Hybrid", "Remote")]

# Define event study weekly indicator terms for regression

invisible(lapply(-20:-1, function(d) {
  event.study.panel[, paste0("inperson_pre_", sprintf("%02d", -1*d)) := ifelse(classroom == "Hybrid" & weeks_to_open == d, 1, 0)]
}))
invisible(lapply(1:30, function(d) {
  event.study.panel[, paste0("inperson_post_", sprintf("%02d", d)) := ifelse(classroom == "Hybrid" & weeks_to_open == d, 1, 0)]
})) 
event.study.panel[, inperson_pre_by_more := ifelse(classroom == "Hybrid" & weeks_to_open < -20, 1, 0)]
event.study.panel[, inperson_post_by_more := ifelse(classroom == "Hybrid" & weeks_to_open > 30, 1, 0)]

# Event study diff-in-diff regression

mod.event.study.weekly <- summary(feols(daily_deaths_per1m ~ 
                                          inperson_pre_20 + inperson_pre_19 + inperson_pre_18 + inperson_pre_17 + inperson_pre_16 + 
                                          inperson_pre_15 + inperson_pre_14 + inperson_pre_13 + inperson_pre_12 + inperson_pre_11 + 
                                          inperson_pre_10 + inperson_pre_09 + inperson_pre_08 + inperson_pre_07 + inperson_pre_06 + 
                                          inperson_pre_05 + inperson_pre_04 + inperson_pre_03 + inperson_pre_02 + inperson_pre_01 + 
                                          inperson_post_01 + inperson_post_02 + inperson_post_03 + inperson_post_04 + inperson_post_05 + 
                                          inperson_post_06 + inperson_post_07 + inperson_post_08 + inperson_post_09 + inperson_post_10 + 
                                          inperson_post_11 + inperson_post_12 + inperson_post_13 + inperson_post_14 + inperson_post_15 +
                                          inperson_post_16 + inperson_post_17 + inperson_post_18 + inperson_post_19 + inperson_post_20 + 
                                          inperson_post_21 + inperson_post_22 + inperson_post_23 + inperson_post_24 + inperson_post_25 +
                                          inperson_post_26 + inperson_post_27 + inperson_post_28 + inperson_post_29 + inperson_post_30 + 
                                          inperson_pre_by_more + inperson_post_by_more
                                        | fips + date, data = event.study.panel), 
                                  cluster = ~ state_name + weeks_to_open)

# Combine coefficients into graph data and determine 95 percent confidence interval for each coefficient

gg.event.study.weekly <- data.table(weeks_to_open = c(-20:-1, 1:30))
gg.event.study.weekly[, coefname := names(coef(mod.event.study.weekly))[1:length(gg.event.study.weekly$weeks_to_open)]]
gg.event.study.weekly[, coef := coef(mod.event.study.weekly)[1:length(gg.event.study.weekly$weeks_to_open)]]
gg.event.study.weekly[, se := se(mod.event.study.weekly)[1:length(gg.event.study.weekly$weeks_to_open)]]
gg.event.study.weekly <- rbind(gg.event.study.weekly, data.table(weeks_to_open = 0, coefname = "inperson_open_week", coef = 0, se = 0))
setkey(gg.event.study.weekly, weeks_to_open)
gg.event.study.weekly[, uci95 := coef + 1.96 * se][, lci95 := coef - 1.96 * se]

# Plot and save graph

ggplot(gg.event.study.weekly, aes(x = weeks_to_open)) +
  geom_hline(yintercept = 0, color = "black") + 
  geom_vline(xintercept = 0, color = "black", linetype = "dashed") +
  annotate("segment", x = -3.5, xend = -0.25, y = 4, yend = 4, arrow = arrow(length = unit(0.25, "cm")), color = "black", size = 0.5) +
  annotate("label", x = -5, y = 4, label = "Start of the\n2020-2021\nschool year", color = "black", size = 4) +
  geom_errorbar(aes(ymin = lci95, ymax = uci95), color = "grey70", width = .1) + 
  geom_point(aes(y = coef), shape = 19, size = 4, color = "#A95AA1") +
  scale_x_continuous(name = "Weeks before (-) or after (+) county started teaching 2020-2021 school year", 
                     limits = c(-20.5, 30.5), breaks = c(-20, -10, 0, 10, 20, 30)) +
  scale_y_continuous(name = "Estimated coefficient: Daily deaths per million pop.", breaks = c(-1, 0, 1, 2, 3, 4), limits = c(-1.5, 5)) +
  theme_bw() + theme(panel.grid = element_blank(), text = element_text(size = 14))

ggsave(file.path(figuresdir, "Figure02B-event-study-daily-covid-deaths-per-million-hybrid.pdf"), width = 10, height = 5, units = "in", dpi = 200)
rm(event.study.panel, mod.event.study.weekly, gg.event.study.weekly)

#### (3) LINE GRAPH OF EMPLOYMENT PER THOUSAND POPULATION WITH 3 GROUPS BY TEACHING METHOD ####

gg.employment <- county.panel[, .(employment_per1k = mean(employment_per1k, na.rm = TRUE)), by = .(classroom, monthdate)]

ggplot(gg.employment, aes(x = monthdate, y = employment_per1k, group = classroom, color = classroom, shape = classroom)) + 
  geom_vline(xintercept = as.Date("2020-08-26"), color = "black", linetype = "dashed") +
  annotate("segment", x = as.Date("2020-07-10"), xend = as.Date("2020-08-21"), y = 490, yend = 490, arrow = arrow(length = unit(0.25, "cm")), color = "black", size = 0.5) +
  annotate("label", x = as.Date("2020-05-30"), y = 490, label = "Start of the\n2020-2021\nschool year\n(post-treatment)", color = "black", size = 4) +
  geom_vline(xintercept = as.Date("2020-02-20"), color = "black", linetype = "dashed") +
  annotate("segment", x = as.Date("2020-01-10"), xend = as.Date("2020-02-15"), y = 420, yend = 420, arrow = arrow(length = unit(0.25, "cm")), color = "black", size = 0.5) +
  annotate("label", x = as.Date("2019-11-28"), y = 420, label = "Start of the\nanalysis panel\n(pre-treatment)", color = "black", size = 4) +
  geom_line(linetype = "dotted") + geom_point(size = 4) +
  scale_x_date(name = "Month", breaks = as.Date(c("2019-01-01", "2019-04-01", "2019-07-01", "2019-10-01", "2020-01-01", "2020-04-01",
                                                  "2020-07-01", "2020-10-01", "2021-01-01", "2021-04-01")), 
               labels = c("Jan-2019", "Apr", "Jul", "Oct", "Jan-2020", "Apr", "Jul", "Oct", "Jan-2021", "Apr"), limits = as.Date(c("2019-01-01", "2021-05-01"))) +
  scale_y_continuous(name = "Employment per thousand population", breaks = c(375, 400, 425, 450, 475, 500), limits = c(375, 500)) + 
  scale_color_manual(name = "Teaching method", values = c("#E66100", "#A95AA1", "#85C0F9")) +
  scale_shape_manual(name = "Teaching method", values = c("C", "H", "R")) +
  theme_bw() + theme(panel.grid = element_blank(), text = element_text(size = 14), 
                     legend.background = element_rect(color = "black", fill = "white"), legend.position = c(0.12, 0.2))

ggsave(file.path(figuresdir, "Figure03-line-graph-employment-school-policy.pdf"), width = 10, height = 5, units = "in", dpi = 200)
rm(gg.employment)

#### (B1) LINE GRAPH OF SHARE OF COUNTIES WITH SCHOOLS STARTED FOR 2020-21AY WITH 3 GROUPS BY TEACHING METHOD ####

county.school.open.panel <- county.panel[date >= "2020-06-01" & date <= "2021-04-01", .(fips, date, open_date, classroom)]
county.school.open.panel[, school_started := ifelse(date >= open_date, 1, 0)]
gg.school.open <- county.school.open.panel[, .(started_counties = sum(school_started), total_counties = .N), by = .(date, classroom)]
gg.school.open[, started_county_share := started_counties / total_counties]
setkey(gg.school.open, date, classroom)

ggplot() +
  geom_line(data = gg.school.open, aes(x = date, y = started_county_share * 100, group = classroom, color = classroom, linetype = classroom), size = 0.6) +
  scale_x_date(name = "Date", breaks = as.Date(c("2020-07-01", "2020-09-01", "2020-11-01", "2021-01-01", "2021-03-01")),
               labels = c("Jul-2020", "Sep", "Nov", "Jan-2021", "Mar"), limits = as.Date(c("2020-06-01", "2021-04-01"))) +
  scale_y_continuous(name = "Share of counties teaching (%)", breaks = c(0, 25, 50, 75, 100), limits = c(0, 100)) + 
  scale_color_manual(name = "Teaching method", values = c("#E66100", "#A95AA1", "#85C0F9")) +
  scale_linetype_manual(name = "Teaching method", values = c("solid", "longdash", "dashed")) +
  theme_bw() + theme(panel.grid = element_blank(), legend.background = element_rect(color = "black", fill = "white"), legend.position = c(0.15, 0.75),
                     axis.title.y.right = element_text(hjust = 0.99), text = element_text(size = 14))

ggsave(file.path(figuresdir, "FigureA01-line-graph-school-started-school-policy.pdf"), width = 10, height = 5, units = "in", dpi = 200)

rm(county.school.open.panel, gg.school.open)

#### (B2) LINE GRAPH OF COMMUNITY MOBILITY MEASURES WITH 2 GROUPS BY TEACHING METHOD (DROP "CAMPUS") ####

gg.mobility <- county.panel[weekdate >= "2020-03-01" & weekdate < "2021-05-30", 
                            lapply(.SD, mean, na.rm = TRUE), by = .(weekdate, classroom) , .SDcols = c(
                              "moveidx_retail_recreation", "moveidx_grocery_pharmacy", "moveidx_workplaces", "moveidx_residential")]

# Retail and recreation

gg.moveidx.retail.recreation <- ggplot(gg.mobility, aes(x = weekdate, y = moveidx_retail_recreation, group = classroom, color = classroom, shape = classroom)) +
  geom_line(size = 0.2) + geom_point(size = 1.5) +
  ggtitle("(a) Retail and recreation") +
  scale_x_date(name = "", breaks = as.Date(c("2020-03-01", "2020-05-01", "2020-07-01", "2020-09-01", "2020-11-01", "2021-01-01", "2021-03-01", "2021-05-01")),
               labels = c("Mar-2020", "May", "Jul", "Sep", "Nov", "Jan-2021", "Mar", "May"), limits = as.Date(c("2020-03-01", "2021-06-01"))) +
  scale_y_continuous(name = "Google mobility index", breaks = c(-50, -25, 0, 25), limits = c(-50, 25)) + 
  scale_color_manual(name = "Teaching method", values = c("#E66100", "#A95AA1", "#85C0F9")) +
  scale_shape_manual(name = "Teaching method", values = c(17, 1, 3)) +
  theme_classic() + theme(legend.background = element_rect(color = "black", fill = "white"), legend.position = "none", text = element_text(size = 14))

# Grocery and pharmacy

gg.moveidx.grocery.pharmacy <- ggplot(gg.mobility, aes(x = weekdate, y = moveidx_grocery_pharmacy, group = classroom, color = classroom, shape = classroom)) + 
  geom_line(size = 0.2) + geom_point(size = 1.5) +
  ggtitle("(b) Grocery and pharmacy") +
  scale_x_date(name = "", breaks = as.Date(c("2020-03-01", "2020-05-01", "2020-07-01", "2020-09-01", "2020-11-01", "2021-01-01", "2021-03-01", "2021-05-01")),
               labels = c("Mar-2020", "May", "Jul", "Sep", "Nov", "Jan-2021", "Mar", "May"), limits = as.Date(c("2020-03-01", "2021-06-01"))) +
  scale_y_continuous(name = "", breaks = c(-50, -25, 0, 25), limits = c(-50, 25)) + 
  scale_color_manual(name = "Teaching method", values = c("#E66100", "#A95AA1", "#85C0F9")) +
  scale_shape_manual(name = "Teaching method", values = c(17, 1, 3)) +
  theme_classic() + theme(legend.background = element_rect(color = "black", fill = "white"), legend.position = "none", text = element_text(size = 14))

# Workplaces

gg.moveidx.workplaces <- ggplot(gg.mobility, aes(x = weekdate, y = moveidx_workplaces, group = classroom, color = classroom, shape = classroom)) + 
  geom_line(size = 0.2) + geom_point(size = 1.5) +
  ggtitle("(c) Workplaces") +
  scale_x_date(name = "Weekly date", breaks = as.Date(c("2020-03-01", "2020-05-01", "2020-07-01", "2020-09-01", "2020-11-01", "2021-01-01", "2021-03-01", "2021-05-01")),
               labels = c("Mar-2020", "May", "Jul", "Sep", "Nov", "Jan-2021", "Mar", "May"), limits = as.Date(c("2020-03-01", "2021-06-01"))) +
  scale_y_continuous(name = "Google mobility index", breaks = c(-50, -25, 0, 25), limits = c(-50, 25)) + 
  scale_color_manual(name = "Teaching method", values = c("#E66100", "#A95AA1", "#85C0F9")) +
  scale_shape_manual(name = "Teaching method", values = c(17, 1, 3)) +
  theme_classic() + theme(legend.background = element_rect(color = "black", fill = "white"), legend.position = "none", text = element_text(size = 14))

# Residential

gg.moveidx.residential <- ggplot(gg.mobility, aes(x = weekdate, y = moveidx_residential, group = classroom, color = classroom, shape = classroom)) + 
  geom_line(size = 0.2) + geom_point(size = 1.5) +
  ggtitle("(d) Residential") +
  scale_x_date(name = "Weekly date", breaks = as.Date(c("2020-03-01", "2020-05-01", "2020-07-01", "2020-09-01", "2020-11-01", "2021-01-01", "2021-03-01", "2021-05-01")),
               labels = c("Mar-2020", "May", "Jul", "Sep", "Nov", "Jan-2021", "Mar", "May"), limits = as.Date(c("2020-03-01", "2021-06-01"))) +
  scale_y_continuous(name = "", breaks = c(-50, -25, 0, 25), limits = c(-50, 25)) + 
  scale_color_manual(name = "Teaching method", values = c("#E66100", "#A95AA1", "#85C0F9")) +
  scale_shape_manual(name = "Teaching method", values = c(17, 1, 3)) +
  theme_classic() + theme(legend.background = element_rect(color = "black", fill = "white"), legend.position = c(0.8, 0.22), text = element_text(size = 14))

## Combine graphs into one figure

comb_graph <- arrangeGrob(gg.moveidx.retail.recreation, gg.moveidx.grocery.pharmacy, gg.moveidx.workplaces, gg.moveidx.residential,
                          nrow = 2, ncol = 2)

ggdraw(comb_graph) 
ggsave(file.path(figuresdir, "FigureA02-line-graph-mobility-school-policy.pdf"), width = 10, height = 8, units = "in", dpi = 200)
rm(gg.mobility, gg.moveidx.retail.recreation, gg.moveidx.grocery.pharmacy, gg.moveidx.workplaces, gg.moveidx.residential, comb_graph)

#### (B3A) LINE GRAPH OF 7-DAY MOVING AVG. DAILY NEW COVID-19 CASES PER MILLION POPULATION WITH 3 GROUPS BY TEACHING METHOD ####

gg.daily.covid <- county.panel[date >= "2020-03-01", .(daily_cases_per1m = mean(daily_cases_per1m, na.rm = TRUE)), by = .(classroom, date)]
setkey(gg.daily.covid, classroom, date)
gg.daily.covid[, daily_cases_per1m_7dma := frollmean(daily_cases_per1m, n = 7), by = classroom]
gg.daily.covid[date < "2020-03-08", daily_cases_per1m_7dma := 0]

gg.opendate.count <- county.panel[date == "2020-03-01", .(county_count = .N), by = .(open_date)]
gg.opendate.count[, share_opening := county_count / sum(county_count)]

ggplot() +
  geom_line(data = gg.daily.covid, aes(x = date, y = daily_cases_per1m_7dma, group = classroom, color = classroom, linetype = classroom), size = 0.6) +
  geom_bar(data = gg.opendate.count, aes(x = open_date, y = share_opening * 500), stat = "identity", color = "grey30", fill = "grey30", width = 1) +
  annotate("segment", x = as.Date("2020-08-26"), xend = as.Date("2020-08-26"), y = 320, yend = 190, arrow = arrow(length = unit(0.25, "cm")), color = "black", size = 0.5) +
  annotate("label", x = as.Date("2020-08-26"), y = 400, label = "Median\nschool\nopening", color = "black", size = 4) +
  scale_x_date(name = "Date", breaks = as.Date(c("2020-03-01", "2020-05-01", "2020-07-01", "2020-09-01", "2020-11-01", "2021-01-01", "2021-03-01", "2021-05-01")),
               labels = c("Mar-2020", "May", "Jul", "Sep", "Nov", "Jan-2021", "Mar", "May"), limits = as.Date(c("2020-03-01", "2021-06-01"))) +
  scale_y_continuous(name = "Daily new COVID-19 cases per million pop. (7DMA)", breaks = c(0, 250, 500, 750, 1000), labels = c("0", "250", "500", "750", "1000"),
                     limits = c(0, 1100), sec.axis = dup_axis(~ . / 5, name = "School openings (%)", breaks = c(0, 10, 20), labels = c("0", "10", "20"))) + 
  scale_color_manual(name = "Teaching method", values = c("#E66100", "#A95AA1", "#85C0F9")) +
  scale_linetype_manual(name = "Teaching method", values = c("solid", "longdash", "dashed")) +
  theme_bw() + theme(panel.grid = element_blank(), legend.background = element_rect(color = "black", fill = "white"), legend.position = c(0.15, 0.75),
                     axis.title.y.right = element_text(hjust = 0.99, vjust = 1), text = element_text(size = 14))

ggsave(file.path(figuresdir, "FigureA03A-line-graph-covid-cases-school-policy.pdf"), width = 10, height = 5, units = "in", dpi = 200)
rm(gg.daily.covid, gg.opendate.count)

#### (B3B) LINE GRAPH OF 7-DAY MOVING AVG. DAILY COVID-19 DEATHS PER MILLION POPULATION WITH 3 GROUPS BY TEACHING METHOD ####

gg.daily.covid <- county.panel[date >= "2020-03-01", .(daily_deaths_per1m = mean(daily_deaths_per1m, na.rm = TRUE)), by = .(classroom, date)]
setkey(gg.daily.covid, classroom, date)
gg.daily.covid[, daily_deaths_per1m_7dma := frollmean(daily_deaths_per1m, n = 7), by = classroom]
gg.daily.covid[date < "2020-03-08", daily_deaths_per1m_7dma := 0]

gg.opendate.count <- county.panel[date == "2020-03-01", .(county_count = .N), by = .(open_date)]
gg.opendate.count[, share_opening := county_count / sum(county_count)]

ggplot() +
  geom_line(data = gg.daily.covid, aes(x = date, y = daily_deaths_per1m_7dma, group = classroom, color = classroom, linetype = classroom), size = 0.6) +
  geom_bar(data = gg.opendate.count, aes(x = open_date, y = share_opening * 10), stat = "identity", color = "grey30", fill = "grey30", width = 1) +
  annotate("segment", x = as.Date("2020-08-26"), xend = as.Date("2020-08-26"), y = 7, yend = 4, arrow = arrow(length = unit(0.25, "cm")), color = "black", size = 0.5) +
  annotate("label", x = as.Date("2020-08-26"), y = 8, label = "Median\nschool\nopening", color = "black", size = 4) +
  scale_x_date(name = "Date", breaks = as.Date(c("2020-03-01", "2020-05-01", "2020-07-01", "2020-09-01", "2020-11-01", "2021-01-01", "2021-03-01", "2021-05-01")),
               labels = c("Mar-2020", "May", "Jul", "Sep", "Nov", "Jan-2021", "Mar", "May"), limits = as.Date(c("2020-03-01", "2021-06-01"))) +
  scale_y_continuous(name = "Daily COVID-19 deaths per million pop. (7DMA)", breaks = c(0, 5, 10, 15, 20), labels = c("0", "5", "10", "15", "20"),
                     limits = c(0, 22), sec.axis = dup_axis(~ . * 10, name = "School openings (%)", breaks = c(0, 10, 20), labels = c("0", "10", "20"))) + 
  scale_color_manual(name = "Teaching method", values = c("#E66100", "#A95AA1", "#85C0F9")) +
  scale_linetype_manual(name = "Teaching method", values = c("solid", "longdash", "dashed")) +
  theme_bw() + theme(panel.grid = element_blank(), legend.background = element_rect(color = "black", fill = "white"), legend.position = c(0.15, 0.75),
                     axis.title.y.right = element_text(hjust = 0.99, vjust = 1), text = element_text(size = 14))

ggsave(file.path(figuresdir, "FigureA03B-line-graph-covid-deaths-school-policy.pdf"), width = 10, height = 5, units = "in", dpi = 200)
rm(gg.daily.covid, gg.opendate.count)

#### END ####
