# Updated 2021 November 08

#### CODE PREAMBLE AND DESCRIPTION ####

## Code preamble: prepare workspace and load R packages

rm(list = ls())     # Clear workspace
library(data.table) # R package for using data.tables as augmented data.frames
library(fixest)     # R package for fixed effects estimation
library(broom)      # R package for used in forming tables
library(dplyr)      # R package for used in forming tables
library(huxtable)   # R package for used in forming tables
library(augsynth)   # R package for synthetic control estimation
datadir = "~/Dropbox/Shared/SchoolsCovid/data" # SET THIS: top-level data directory
tablesdir = "~/Dropbox/Shared/SchoolsCovid/tables" # SET THIS: directory in which to save tables
setwd(datadir)

## List of Tables:
#  1) Summary statistics "balance" table, with three groups by teaching method
#  2) Regression table for employment outcomes, with three groups by teaching method
# B1) Regression table for COVID outcomes, with three groups by teaching method
# B2) Regression table for COVID outcomes, with three groups by teaching method -- only states with any Campus teaching counties
# B3) Regression table for *daily* and *monthly* COVID outcomes, with three groups by teaching method
# B4) Regression table for employment outcomes, with three groups by teaching method -- only states with any Campus teaching counties
# X1) Additional results (not saved as a table) for regression of change in COVID-19 deaths within county during school year by teaching method.
# X2) Synthetic control estimations for employment outcomes (not saved as a table) for robustness checks
# X3) Synthetic control estimations for COVID-19 outcomes (not saved as a table) for robustness checks
# X4) Google mobility index for workplaces -- difference in differences estimates (not saved as a table)
#

## Data and programming notes:
#
# 1. Running this code requires about 4 GB of RAM.
#
# 2. Uses data prepared in code step "1_Compile_Data.R"
#

#### LOAD AND PREPARE DATA ####

setwd(datadir)

# Read in data in county panel

county.panel <- fread("county_panel.csv")

# Define COVID cases per million population, deaths per million population, and employment per thousand population

county.panel[, cumulative_cases_per1m := cumulative_cases / (population / 1000000)]
county.panel[, cumulative_deaths_per1m := cumulative_deaths / (population / 1000000)]
county.panel[, daily_cases_per1m := daily_cases / (population / 1000000)]
county.panel[, daily_deaths_per1m := daily_deaths / (population / 1000000)]
county.panel[, employment_per1k := employment / (population / 1000)]

# Define an indicator for school having opened for 2020-21 school year, and an indicator for this by teaching method

county.panel[, school_open := ifelse(date >= open_date, 1L, 0L)]
county.panel[, teaching_remote := ifelse(classroom == "Remote" & date >= open_date, 1L, 0L)]
county.panel[, teaching_hybrid := ifelse(classroom == "Hybrid" & date >= open_date, 1L, 0L)]
county.panel[, teaching_campus := ifelse(classroom == "Campus" & date >= open_date, 1L, 0L)]

# Define indicators for missing movement index data, missing COVID tests data, and missing COVID policy data (very rare in latter case)

county.panel[, missing_moveidx_retail_recreation := ifelse(is.na(moveidx_retail_recreation), 1, 0)]
county.panel[, missing_moveidx_grocery_pharmacy := ifelse(is.na(moveidx_grocery_pharmacy), 1, 0)]
county.panel[, missing_moveidx_parks := ifelse(is.na(moveidx_parks), 1, 0)]
county.panel[, missing_moveidx_transit := ifelse(is.na(moveidx_transit), 1, 0)]
county.panel[, missing_moveidx_workplaces := ifelse(is.na(moveidx_workplaces), 1, 0)]
county.panel[, missing_moveidx_residential := ifelse(is.na(moveidx_residential), 1, 0)]
county.panel[, missing_daily_test_volume := ifelse(is.na(daily_test_volume), 1, 0)]
county.panel[, missing_total_covid_ordinances := ifelse(is.na(total_covid_ordinances), 1, 0)]

county.panel[missing_moveidx_retail_recreation == 1, moveidx_retail_recreation := -999]
county.panel[missing_moveidx_grocery_pharmacy == 1, moveidx_grocery_pharmacy := -999]
county.panel[missing_moveidx_parks == 1, moveidx_parks := -999]
county.panel[missing_moveidx_transit == 1, moveidx_transit := -999]
county.panel[missing_moveidx_workplaces == 1, moveidx_workplaces := -999]
county.panel[missing_moveidx_residential == 1, moveidx_residential := -999]
county.panel[missing_daily_test_volume == 1, daily_test_volume := -999]
county.panel[missing_total_covid_ordinances == 1, total_covid_ordinances := -999]

# Define indicators for whether each *state* has any Campus teaching counties

campus.states <- unique(county.panel[classroom == "Campus", .(state_name, state_any_campus = "Yes")], by = NULL)
county.panel <- merge(county.panel, campus.states, by = "state_name", all.x = TRUE)
county.panel[is.na(state_any_campus), state_any_campus := "No"]

#### (1) SUMMARY STATISTICS "BALANCE" TABLE, WITH THREE GROUPS BY TEACHING METHOD ####

setkey(county.panel, classroom)

## Panel [A] Predetermined county covariates in 2019

county.cs <- county.panel[date == "2020-03-01"]

sum_stats_2019 <- county.cs[, lapply(.SD, mean, na.rm = TRUE), by = classroom, .SDcols = c(
   "latitude", "longitude", "population", "pop_u18_pct", "adult_lfpr", "female_lfpr", "mothers_lfpr",
   "nominal_gdp", "median_income", "poverty_rate", "flu_vaccine_rate", "hospital_total_beds", "hospital_icu_beds")]

# Calculate the per-capita outcomes this way so they are population-weighted to represent national values rather than equally-weighting counties
sum_stats_2019[, nominal_gdp_percap := 1000 * nominal_gdp / population] # Converting to dollars-per-capita from $1000 denoted values
sum_stats_2019[, hospital_beds_perthou := hospital_total_beds / (population / 1000)]
sum_stats_2019[, icu_beds_perthou := hospital_icu_beds / (population / 1000)]
sum_stats_2019$nominal_gdp <- NULL
sum_stats_2019$hospital_total_beds <- NULL
sum_stats_2019$hospital_icu_beds <- NULL

# Format fields
sum_stats_2019[, latitude := sprintf("%2.2f", latitude)]
sum_stats_2019[, longitude := sprintf("%2.2f", longitude)]
sum_stats_2019[, population := sprintf("%6.0f", population)]
sum_stats_2019[, pop_u18_pct := sprintf("%2.2f", pop_u18_pct)]
sum_stats_2019[, adult_lfpr := sprintf("%2.2f", adult_lfpr)]
sum_stats_2019[, female_lfpr := sprintf("%2.2f", female_lfpr)]
sum_stats_2019[, mothers_lfpr := sprintf("%2.2f", mothers_lfpr)]
sum_stats_2019[, nominal_gdp_percap := sprintf("%5.0f", nominal_gdp_percap)]
sum_stats_2019[, median_income := sprintf("%5.0f", median_income)]
sum_stats_2019[, poverty_rate := sprintf("%2.2f", poverty_rate)]
sum_stats_2019[, flu_vaccine_rate := sprintf("%2.2f", flu_vaccine_rate)]
sum_stats_2019[, hospital_beds_perthou := sprintf("%2.2f", hospital_beds_perthou)]
sum_stats_2019[, icu_beds_perthou := sprintf("%2.2f", icu_beds_perthou)]

setcolorder(sum_stats_2019, c("classroom", "latitude", "longitude", "population", "pop_u18_pct", "adult_lfpr", "female_lfpr", 
                              "mothers_lfpr", "nominal_gdp_percap", "median_income", "poverty_rate", "flu_vaccine_rate", 
                              "hospital_beds_perthou", "icu_beds_perthou"))

sum_stats_2019 <- cbind(c("", "Latitude", "Longitude", "Population", "Population share under-18 (%)", "Adult labor force part. rate (%)", 
                          "Female labor force part. rate (%)", "Mothers labor force part. rate (%)", "GDP per person ($)", "Median income ($)", 
                          "Poverty rate (%)", "Influenza vaccinations rate (%)", "Hospital beds per 1k population", 
                          "ICU beds per 1k population"), t(sum_stats_2019))

## Panel [B] Outcomes during March 2020 through May 2021

sum_stats_outcomes <- county.panel[date >= "2020-03-01", lapply(.SD, mean, na.rm = TRUE), by = classroom, .SDcols = c(
   "daily_cases_per1m", "daily_deaths_per1m", "employment_per1k")]

# Format fields
sum_stats_outcomes[, daily_cases_per1m := sprintf("%3.0f", daily_cases_per1m)]
sum_stats_outcomes[, daily_deaths_per1m := sprintf("%2.2f", daily_deaths_per1m)]
sum_stats_outcomes[, employment_per1k := sprintf("%3.0f", employment_per1k)]
sum_stats_outcomes <- sum_stats_outcomes[, .(daily_cases_per1m, daily_deaths_per1m, employment_per1k)]

sum_stats_outcomes <- cbind(c("Daily COVID-19 cases per 1m pop.", "Daily COVID-19 deaths per 1m pop.", "Employment per 1k population"), 
                            t(sum_stats_outcomes))

# Bottom panel with county count and school start dates

bottom_panel <- rbind(cbind("Start of 2020-2021 school year", t(county.panel[, .(format(mean(open_date), "%B %d")), by = classroom][,2])), 
                      cbind("Number of counties", t(county.cs[, formatC(.N,  big.mark = ","), by = classroom][,2])))

## Form and save summary statistics table as .tex using huxtable

sum_stats <- rbind(sum_stats_2019, sum_stats_outcomes, bottom_panel)
statstable <- huxtable(sum_stats) %>%
   insert_row(c("", "Average across counties", "", ""), after = 0) %>% merge_across(row = 1, col = 2:4) %>% 
   insert_row(c("Panel [A] Pre-pandemic covariates in 2019", "", "", ""), after = 2) %>% merge_across(row = 3, col = 1:4) %>% 
   insert_row(c("Panel [B] Dependent variables during March 2020 - May 2021", "", "", ""), after = 16) %>% merge_across(row = 17, col = 1:4) %>% 
   set_align(col = 1, value = "left") %>% set_align(col = 2:4, value = "right") %>%
   set_align(row = 1, col = 2:4, value = "center") %>%
   set_bold(row = c(3,17), value = TRUE) %>%
   set_tb_padding(value = 0) %>% set_tb_padding(row = c(2, 3 , 17), value = 8) %>% 
   set_top_padding(row = c(1,21), value = 4) %>%
   set_bottom_padding(row = c(1,16,17,20,22), value = 8) %>%
   set_top_border(row = 1, value = 1) %>% 
   set_bottom_border(row = 1, col = 2:4, value = 0.4) %>%
   set_bottom_border(row = c(2, 16), value = 0.4) %>%
   set_bottom_border(row = 20, value = 0.4) %>%
   set_bottom_border(row = 22, value = 1) %>% 
   set_number_format(row = c(4:16, 19:20), value = fmt_pretty())
statstable

font_size(statstable) <- 10
sink(file.path(tablesdir, "Summary_Statistics.tex"))
print_latex(statstable, tabular_only = TRUE)
sink()

rm(sum_stats, sum_stats_2019, sum_stats_outcomes, bottom_panel, statstable, county.cs)

#### (2) REGRESSION TABLE FOR EMPLOYMENT OUTCOMES, WITH TWO GROUPS OF HYBRID AND REMOTE ####

# Prepare panel to use for these regressions

employment.panel <- county.panel[date == monthdate & !is.na(employment) & date >= "2020-03-01"]
employment.panel[, amed_mothers_lfpr := ifelse(mothers_lfpr > median(mothers_lfpr, na.rm = T), 1, 0)]
employment.panel[, amed_poverty_rate := ifelse(poverty_rate > median(poverty_rate, na.rm = T), 1, 0)]
temp.covid.august31 <- county.panel[date == "2020-08-31", .(fips, cumulative_deaths_per1m)]
temp.covid.august31[, county_death_pctl  := frank(cumulative_deaths_per1m) / .N]
temp.covid.august31[, bmed_deaths_pct := ifelse(county_death_pctl < 0.5, 1, 0)]
employment.panel <- merge(employment.panel, temp.covid.august31[, .(fips, bmed_deaths_pct)], by = "fips")
rm(temp.covid.august31)

# Column (1): natural log of employment, with county and month fixed effects, no controls

mod.logemp.nocon <- summary(feols(log(employment) ~ teaching_campus + teaching_hybrid | fips + monthdate, data = employment.panel), 
                            cluster = ~ state_name + monthdate)

# Column (2): employment per thousand population, with county and month fixed effects, no controls

mod.emp.pop.nocon <- summary(feols(employment_per1k ~ teaching_campus + teaching_hybrid | fips + monthdate, data = employment.panel), 
                             cluster = ~ state_name + monthdate)

# Column (3): employment per thousand population, with county and month fixed effects, no controls: counties with above-median 2019 mother LFPR

mod.emp.pop.nocon.amed.lfpr <- summary(feols(employment_per1k ~ teaching_campus + teaching_hybrid | fips + monthdate, data = employment.panel[amed_mothers_lfpr == 1]), 
                                       cluster = ~ state_name + monthdate)

# Column (4): employment per thousand population, with county and month fixed effects, no controls: counties with above-median 2019 poverty rate

mod.emp.pop.nocon.amed.poverty <- summary(feols(employment_per1k ~ teaching_campus + teaching_hybrid | fips + monthdate, data = employment.panel[amed_poverty_rate == 1]), 
                                          cluster = ~ state_name + monthdate)

# Column (5): employment per thousand population, with county and month fixed effects, no controls: counties with BELOW-median COVID-19 deaths through August 31, 2020

mod.emp.pop.nocon.bmed.deaths <- summary(feols(employment_per1k ~ teaching_campus + teaching_hybrid | fips + monthdate, data = employment.panel[bmed_deaths_pct == 1]), 
                                         cluster = ~ state_name + monthdate)

# Statistics for table
mean_log_employment <- sprintf("%3.2f", mean(log(employment.panel$employment)))
mean_employment_per1k <- sprintf("%4.2f", mean(employment.panel$employment_per1k))
mean_employment_per1k_amed_mothers_lfpr <- sprintf("%4.2f", mean(employment.panel[amed_mothers_lfpr == 1]$employment_per1k))
mean_employment_per1k_amed_poverty_rate <- sprintf("%4.2f", mean(employment.panel[amed_poverty_rate == 1]$employment_per1k))
mean_employment_per1k_bmed_deaths_pct <- sprintf("%4.2f", mean(employment.panel[bmed_deaths_pct == 1]$employment_per1k))
county_ct_all <- formatC(length(unique(employment.panel$fips)), big.mark = ",")
county_ct_amed_mothers_lfpr <- formatC(length(unique(employment.panel[amed_mothers_lfpr == 1]$fips)), big.mark = ",")
county_ct_amed_poverty_rate <- formatC(length(unique(employment.panel[amed_poverty_rate == 1]$fips)), big.mark = ",")
county_ct_bmed_deaths_pct <- formatC(length(unique(employment.panel[bmed_deaths_pct == 1]$fips)), big.mark = ",")

stats.rows <- huxtable(rbind(c("Dep. variable mean", mean_log_employment, mean_employment_per1k, mean_employment_per1k_amed_mothers_lfpr,
                               mean_employment_per1k_amed_poverty_rate, mean_employment_per1k_bmed_deaths_pct),
                             c("County fixed effects", "Yes", "Yes", "Yes", "Yes", "Yes"),
                             c("Month fixed effects", "Yes", "Yes", "Yes", "Yes", "Yes"),
                             c("Number of counties", county_ct_all, county_ct_all, county_ct_amed_mothers_lfpr, county_ct_amed_poverty_rate, county_ct_bmed_deaths_pct)
))

# Form and save regression output table as .tex using huxtable

regtable.employment <- huxreg(mod.logemp.nocon, mod.emp.pop.nocon, mod.emp.pop.nocon.amed.lfpr, mod.emp.pop.nocon.amed.poverty, mod.emp.pop.nocon.bmed.deaths, 
                              coefs = c("Teaching: Campus" = "teaching_campus", "Teaching: Hybrid" = "teaching_hybrid"),
                              statistics = c("Observations" = "nobs", "Adj. R-squared" = "adj.r.squared"), note = "", stars = c(`*` = 0.1, `**` = 0.05, `***` = 0.01)) %>%
   insert_row(c("", "Log-Emp.", "Employment per 1k population", "", "", ""), copy_cell_props = FALSE, after = 0) %>%
   merge_across(row = 1, col = 3:6) %>%
   insert_row(c("", "All counties", "All counties", "Abv. median", "Abv. median", "Blw. median"), copy_cell_props = FALSE, after = 1) %>%
   insert_row(c("", "", "", "mother LFPR", "poverty rate", "COVID deaths"), copy_cell_props = FALSE, after = 2) %>%
   insert_row(c("", "", "", "in 2019", "in 2019", "pre-Sep. 2020"), copy_cell_props = FALSE, after = 3) %>%
   add_rows(stats.rows, after = 9, copy_cell_props = FALSE) %>%
   set_align(col = 1, value = "left") %>% set_align(col = 2:6, value = "center") %>% 
   set_tb_padding(value = 0) %>% set_tb_padding(row = 5, value = 6) %>%
   set_top_padding(row = c(1,2,10), value = 4) %>% set_top_padding(row = 6, value = 8) %>%
   set_bottom_padding(row = 1, value = 6) %>% set_bottom_padding(row = 15, value = 8) %>%
   set_bottom_padding(row = c(7,9), value = 18) %>%
   set_top_border(row = 1, value = 1) %>% set_bottom_border(row = 1, col = 3:6, value = 0.4) %>%
   set_number_format(row = 4, value = fmt_pretty(big.mark = "")) %>%
   set_number_format(row = 6:9, col = 2, value = "%1.3f") %>%
   set_number_format(row = 6:9, col = 3:6, value = "%1.2f") %>%   
   set_number_format(row = 14, value = fmt_pretty())
regtable.employment
font_size(regtable.employment) <- 10
sink(file.path(tablesdir, "Regressions_Employment.tex"))
print_latex(regtable.employment, tabular_only = TRUE)
sink()

# Clean workspace

rm(mod.emp.pop.nocon, mod.logemp.nocon, mod.emp.pop.nocon.amed.lfpr, mod.emp.pop.nocon.amed.poverty, mod.emp.pop.nocon.bmed.deaths,
   employment.panel, regtable.employment, mean_employment_per1k, mean_employment_per1k_amed_mothers_lfpr,
   mean_employment_per1k_amed_poverty_rate, mean_employment_per1k_bmed_deaths_pct, mean_log_employment, county_ct_all,
   county_ct_amed_mothers_lfpr, county_ct_amed_poverty_rate, county_ct_bmed_deaths_pct, stats.rows)

#### (B1) REGRESSION TABLE FOR COVID CASES AND DEATHS, WITH TWO GROUPS OF HYBRID AND REMOTE ####

# Prepare panel to use for these regressions

covid.panel <- county.panel[date >= "2020-03-01"]

# 14 day lag of deaths per million (can be used for comparison to literature / robustness check)
covid.panel[, lag14_daily_deaths_per1m := shift(daily_deaths_per1m, type = "lag", n = 14)]
covid.panel[fips != shift(fips, type = "lag", n = 14), lag14_daily_deaths_per1m := NA]

# 21 day lag of deaths per million (can be used for comparison to literature / robustness check)
covid.panel[, lag21_daily_deaths_per1m := shift(daily_deaths_per1m, type = "lag", n = 21)]
covid.panel[fips != shift(fips, type = "lag", n = 21), lag21_daily_deaths_per1m := NA]

# Column (1): OLS, daily cases per million population, with county and date fixed effects, and NO controls

mod.ols.dailycasespop.nocontrols <- summary(feols(daily_cases_per1m ~ teaching_campus + teaching_hybrid
                                                | fips + date, data = covid.panel), cluster = ~ state_name + date)

# Column (2): OLS, daily cases per million population, with county and date fixed effects, and controls for mobility and COVID policies

mod.ols.dailycasespop.controls <- summary(feols(daily_cases_per1m ~ teaching_campus + teaching_hybrid + moveidx_retail_recreation + 
                                                   moveidx_grocery_pharmacy + moveidx_parks + moveidx_transit + moveidx_workplaces + 
                                                   moveidx_residential + daily_test_volume + total_covid_ordinances + 
                                                   missing_moveidx_retail_recreation + missing_moveidx_grocery_pharmacy + missing_moveidx_parks + 
                                                   missing_moveidx_transit + missing_moveidx_workplaces + missing_moveidx_residential + 
                                                   missing_daily_test_volume + missing_total_covid_ordinances
                                                | fips + date, data = covid.panel), cluster = ~ state_name + date)

# Column (3): OLS, daily deaths per million population, with county and date fixed effects, and NO controls

mod.ols.dailydeathspop.nocontrols <- summary(feols(daily_deaths_per1m ~ teaching_campus + teaching_hybrid
                                                   | fips + date, data = covid.panel), cluster = ~ state_name + date)

# Column (4): OLS, daily deaths per million population, with county and date fixed effects, and controls for mobility and COVID policies

mod.ols.dailydeathspop.controls <- summary(feols(daily_deaths_per1m ~ teaching_campus + teaching_hybrid + moveidx_retail_recreation + 
                                                    moveidx_grocery_pharmacy + moveidx_parks + moveidx_transit + moveidx_workplaces + 
                                                    moveidx_residential + daily_test_volume + total_covid_ordinances + 
                                                    missing_moveidx_retail_recreation + missing_moveidx_grocery_pharmacy + missing_moveidx_parks + 
                                                    missing_moveidx_transit + missing_moveidx_workplaces + missing_moveidx_residential + 
                                                    missing_daily_test_volume + missing_total_covid_ordinances
                                                 | fips + date, data = covid.panel), cluster = ~ state_name + date)

# Statistics for table
population_campus <- sum(covid.panel[date == "2021-05-31" & classroom == "Campus"]$population)
population_hybrid <- sum(covid.panel[date == "2021-05-31" & classroom == "Hybrid"]$population)
population_remote <- sum(covid.panel[date == "2021-05-31" & classroom == "Remote"]$population)
population_total <- population_campus + population_hybrid + population_remote
population_share_campus <- sprintf("%2.1f", 100 * population_campus / population_total)
population_share_hybrid <- sprintf("%2.1f", 100 * population_hybrid / population_total)

mean_daily_cases_per1m_schoolyear <- sprintf("%3.2f", mean(covid.panel[date >= "2020-09-01"]$daily_cases_per1m))
mean_daily_deaths_per1m_schoolyear <- sprintf("%3.2f", mean(covid.panel[date >= "2020-09-01"]$daily_deaths_per1m))
county_ct_all <- formatC(length(unique(covid.panel$fips)), big.mark = ",")

# Compute aggregate effect sizes

agg.dailycasespop.nocontrols <- round(
   coef(mod.ols.dailycasespop.nocontrols)[[1]] * population_campus/1000000 +
   coef(mod.ols.dailycasespop.nocontrols)[[2]] * population_hybrid/1000000)

agg.dailycasespop.controls <- round(
   coef(mod.ols.dailycasespop.controls)[[1]] * population_campus/1000000 +
      coef(mod.ols.dailycasespop.controls)[[2]] * population_hybrid/1000000)

agg.dailydeathspop.nocontrols <- round(
   coef(mod.ols.dailydeathspop.nocontrols)[[1]] * population_campus/1000000 +
      coef(mod.ols.dailydeathspop.nocontrols)[[2]] * population_hybrid/1000000)

agg.dailydeathspop.controls <- round(
   coef(mod.ols.dailydeathspop.controls)[[1]] * population_campus/1000000 +
      coef(mod.ols.dailydeathspop.controls)[[2]] * population_hybrid/1000000)

agg.national.cases <- round(sum(covid.panel[date == "2021-05-31"]$population/1000000) * mean(covid.panel[date >= "2020-09-01"]$daily_cases_per1m)) 
agg.national.deaths <- round(sum(covid.panel[date == "2021-05-31"]$population/1000000) * mean(covid.panel[date >= "2020-09-01"]$daily_deaths_per1m)) 

stats.rows <- huxtable(rbind(
   c("Dep. variable mean", mean_daily_cases_per1m_schoolyear, mean_daily_cases_per1m_schoolyear, 
     mean_daily_deaths_per1m_schoolyear, mean_daily_deaths_per1m_schoolyear),
   c("(during school year)", "", "", "", ""),
   c("U.S. daily total", agg.national.cases, agg.national.cases,agg.national.deaths, agg.national.deaths),
   c("(during school year)", "", "", "", ""),
   c("Controls", "No", "Yes", "No", "Yes"),
   c("County fixed effects", "Yes", "Yes", "Yes", "Yes"),
   c("Date fixed effects", "Yes", "Yes", "Yes", "Yes"),
   c("Number of counties", county_ct_all, county_ct_all, county_ct_all, county_ct_all)
))

# Form and save regression output table as .tex using huxtable

regtable.covid <- huxreg(mod.ols.dailycasespop.nocontrols, mod.ols.dailycasespop.controls, 
                         mod.ols.dailydeathspop.nocontrols, mod.ols.dailydeathspop.controls,
                         coefs = c("Teaching: Campus" = "teaching_campus", "Teaching: Hybrid" = "teaching_hybrid"),
                         statistics = c("Observations" = "nobs"), note = "", stars = c(`*` = 0.1, `**` = 0.05, `***` = 0.01)) %>%
   insert_row(c("", "Daily new cases per 1m pop.", "", "Daily deaths per 1m pop.", ""), copy_cell_props = FALSE, after = 0) %>%
   insert_row(c("Aggregate effect size", agg.dailycasespop.nocontrols, agg.dailycasespop.controls,
                agg.dailydeathspop.nocontrols, agg.dailydeathspop.controls), after = 6) %>%
   add_rows(stats.rows, after = 7, copy_cell_props = FALSE) %>%
   insert_column(c("Population (m)", "", population_campus/1000000, "", population_hybrid/1000000), after = 1, fill = "") %>%
   merge_across(row = 1, col = 3:4) %>% merge_across(row = 1, col = 5:6) %>%
   set_align(col = 1, value = "left") %>% set_align(col = 2:6, value = "center") %>% 
   set_tb_padding(value = 0) %>% set_tb_padding(row = 2, value = 6) %>%
   set_top_padding(row = c(1, 7, 8), value = 4) %>% set_top_padding(row = 3, value = 8) %>%
   set_bottom_padding(row = 14, value = 8) %>%
   set_bottom_padding(row = c(4,6,7), value = 18) %>%
   set_top_border(row = 1, value = 1) %>% set_bottom_border(row = 1, col = 3:6, value = 0.4) %>%
   set_bottom_border(row = 2, col = 2:6, value = 0.4) %>%
   set_bottom_border(row = 6, col = 3:6, value = 0.4) %>%
   set_number_format(row = 3:6, col = 2:6, value = "%2.2f") %>%
   set_number_format(row = c(7:10, 16), value = fmt_pretty())
regtable.covid
font_size(regtable.covid) <- 10
sink(file.path(tablesdir, "Regressions_Covid.tex"))
print_latex(regtable.covid, tabular_only = TRUE)
sink()

# Clean workspace

rm(mod.ols.dailycasespop.nocontrols, mod.ols.dailycasespop.controls, mod.ols.dailydeathspop.nocontrols, mod.ols.dailydeathspop.controls,
   stats.rows, county_ct_all, covid.panel, regtable.covid, mean_daily_cases_per1m_schoolyear, mean_daily_deaths_per1m_schoolyear,
   population_campus, population_hybrid, population_remote, population_share_campus, population_share_hybrid,
   agg.dailycasespop.nocontrols, agg.dailycasespop.controls, agg.dailydeathspop.nocontrols, agg.dailydeathspop.controls,
   agg.national.cases, agg.national.deaths)

#### (B2) REGRESSION TABLE FOR COVID CASES AND DEATHS, WITH TWO GROUPS OF HYBRID AND REMOTE -- ONLY STATES WITH ANY CAMPUS COUNTIES ####

# Prepare panel to use for these regressions

covid.panel <- county.panel[date >= "2020-03-01" & state_any_campus == "Yes"]

# Column (1): OLS, daily cases per million population, with county and date fixed effects, and NO controls

mod.ols.dailycasespop.nocontrols <- summary(feols(daily_cases_per1m ~ teaching_campus + teaching_hybrid
                                                  | fips + date, data = covid.panel), cluster = ~ state_name + date)

# Column (2): OLS, daily cases per million population, with county and date fixed effects, and controls for mobility and COVID policies

mod.ols.dailycasespop.controls <- summary(feols(daily_cases_per1m ~ teaching_campus + teaching_hybrid + moveidx_retail_recreation + 
                                                  moveidx_grocery_pharmacy + moveidx_parks + moveidx_transit + moveidx_workplaces + 
                                                  moveidx_residential + daily_test_volume + total_covid_ordinances + 
                                                  missing_moveidx_retail_recreation + missing_moveidx_grocery_pharmacy + missing_moveidx_parks + 
                                                  missing_moveidx_transit + missing_moveidx_workplaces + missing_moveidx_residential + 
                                                  missing_daily_test_volume + missing_total_covid_ordinances
                                                | fips + date, data = covid.panel), cluster = ~ state_name + date)

# Column (3): OLS, daily deaths per million population, with county and date fixed effects, and NO controls

mod.ols.dailydeathspop.nocontrols <- summary(feols(daily_deaths_per1m ~ teaching_campus + teaching_hybrid
                                                   | fips + date, data = covid.panel), cluster = ~ state_name + date)

# Column (4): OLS, daily deaths per million population, with county and date fixed effects, and controls for mobility and COVID policies

mod.ols.dailydeathspop.controls <- summary(feols(daily_deaths_per1m ~ teaching_campus + teaching_hybrid + moveidx_retail_recreation + 
                                                   moveidx_grocery_pharmacy + moveidx_parks + moveidx_transit + moveidx_workplaces + 
                                                   moveidx_residential + daily_test_volume + total_covid_ordinances + 
                                                   missing_moveidx_retail_recreation + missing_moveidx_grocery_pharmacy + missing_moveidx_parks + 
                                                   missing_moveidx_transit + missing_moveidx_workplaces + missing_moveidx_residential + 
                                                   missing_daily_test_volume + missing_total_covid_ordinances
                                                 | fips + date, data = covid.panel), cluster = ~ state_name + date)

# Statistics for table
population_campus <- sum(covid.panel[date == "2021-05-31" & classroom == "Campus"]$population)
population_hybrid <- sum(covid.panel[date == "2021-05-31" & classroom == "Hybrid"]$population)
population_remote <- sum(covid.panel[date == "2021-05-31" & classroom == "Remote"]$population)
population_total <- population_campus + population_hybrid + population_remote
population_share_campus <- sprintf("%2.1f", 100 * population_campus / population_total)
population_share_hybrid <- sprintf("%2.1f", 100 * population_hybrid / population_total)

mean_daily_cases_per1m_schoolyear <- sprintf("%3.2f", mean(covid.panel[date >= "2020-09-01"]$daily_cases_per1m))
mean_daily_deaths_per1m_schoolyear <- sprintf("%3.2f", mean(covid.panel[date >= "2020-09-01"]$daily_deaths_per1m))
county_ct_all <- formatC(length(unique(covid.panel$fips)), big.mark = ",")

# Compute aggregate effect sizes

agg.dailycasespop.nocontrols <- round(
  coef(mod.ols.dailycasespop.nocontrols)[[1]] * population_campus/1000000 +
    coef(mod.ols.dailycasespop.nocontrols)[[2]] * population_hybrid/1000000)

agg.dailycasespop.controls <- round(
  coef(mod.ols.dailycasespop.controls)[[1]] * population_campus/1000000 +
    coef(mod.ols.dailycasespop.controls)[[2]] * population_hybrid/1000000)

agg.dailydeathspop.nocontrols <- round(
  coef(mod.ols.dailydeathspop.nocontrols)[[1]] * population_campus/1000000 +
    coef(mod.ols.dailydeathspop.nocontrols)[[2]] * population_hybrid/1000000)

agg.dailydeathspop.controls <- round(
  coef(mod.ols.dailydeathspop.controls)[[1]] * population_campus/1000000 +
    coef(mod.ols.dailydeathspop.controls)[[2]] * population_hybrid/1000000)

agg.national.cases <- round(sum(covid.panel[date == "2021-05-31"]$population/1000000) * mean(covid.panel[date >= "2020-09-01"]$daily_cases_per1m)) 
agg.national.deaths <- round(sum(covid.panel[date == "2021-05-31"]$population/1000000) * mean(covid.panel[date >= "2020-09-01"]$daily_deaths_per1m)) 

stats.rows <- huxtable(rbind(
  c("Dep. variable mean", mean_daily_cases_per1m_schoolyear, mean_daily_cases_per1m_schoolyear, 
    mean_daily_deaths_per1m_schoolyear, mean_daily_deaths_per1m_schoolyear),
  c("(during school year)", "", "", "", ""),
  c("U.S. daily total", agg.national.cases, agg.national.cases,agg.national.deaths, agg.national.deaths),
  c("(during school year)", "", "", "", ""),
  c("Controls", "No", "Yes", "No", "Yes"),
  c("County fixed effects", "Yes", "Yes", "Yes", "Yes"),
  c("Date fixed effects", "Yes", "Yes", "Yes", "Yes"),
  c("Number of counties", county_ct_all, county_ct_all, county_ct_all, county_ct_all)
))

# Form and save regression output table as .tex using huxtable

regtable.covid <- huxreg(mod.ols.dailycasespop.nocontrols, mod.ols.dailycasespop.controls, 
                         mod.ols.dailydeathspop.nocontrols, mod.ols.dailydeathspop.controls,
                         coefs = c("Teaching: Campus" = "teaching_campus", "Teaching: Hybrid" = "teaching_hybrid"),
                         statistics = c("Observations" = "nobs"), note = "", stars = c(`*` = 0.1, `**` = 0.05, `***` = 0.01)) %>%
  insert_row(c("", "Daily new cases per 1m pop.", "", "Daily deaths per 1m pop.", ""), copy_cell_props = FALSE, after = 0) %>%
  insert_row(c("Aggregate effect size", agg.dailycasespop.nocontrols, agg.dailycasespop.controls,
               agg.dailydeathspop.nocontrols, agg.dailydeathspop.controls), after = 6) %>%
  add_rows(stats.rows, after = 7, copy_cell_props = FALSE) %>%
  insert_column(c("Population (m)", "", population_campus/1000000, "", population_hybrid/1000000), after = 1, fill = "") %>%
  merge_across(row = 1, col = 3:4) %>% merge_across(row = 1, col = 5:6) %>%
  set_align(col = 1, value = "left") %>% set_align(col = 2:6, value = "center") %>% 
  set_tb_padding(value = 0) %>% set_tb_padding(row = 2, value = 6) %>%
  set_top_padding(row = c(1, 7, 8), value = 4) %>% set_top_padding(row = 3, value = 8) %>%
  set_bottom_padding(row = 14, value = 8) %>%
  set_bottom_padding(row = c(4,6,7), value = 18) %>%
  set_top_border(row = 1, value = 1) %>% set_bottom_border(row = 1, col = 3:6, value = 0.4) %>%
  set_bottom_border(row = 2, col = 2:6, value = 0.4) %>%
  set_bottom_border(row = 6, col = 3:6, value = 0.4) %>%
  set_number_format(row = 3:6, col = 2:6, value = "%2.2f") %>%
  set_number_format(row = c(7:10, 16), value = fmt_pretty())
regtable.covid
font_size(regtable.covid) <- 10
sink(file.path(tablesdir, "Regressions_Covid_States_Any_Campus.tex"))
print_latex(regtable.covid, tabular_only = TRUE)
sink()

# Clean workspace

rm(mod.ols.dailycasespop.nocontrols, mod.ols.dailycasespop.controls, mod.ols.dailydeathspop.nocontrols, mod.ols.dailydeathspop.controls,
   stats.rows, county_ct_all, covid.panel, regtable.covid, mean_daily_cases_per1m_schoolyear, mean_daily_deaths_per1m_schoolyear,
   population_campus, population_hybrid, population_remote, population_share_campus, population_share_hybrid,
   agg.dailycasespop.nocontrols, agg.dailycasespop.controls, agg.dailydeathspop.nocontrols, agg.dailydeathspop.controls,
   agg.national.cases, agg.national.deaths)

#### (B3) REGRESSION TABLE FOR * DAILY * AND FOR * MONTHLY * COVID CASES AND DEATHS, WITH TWO GROUPS OF HYBRID AND REMOTE ####

# Prepare daily and monthly panels to use for these regressions

covid.panel.daily <- county.panel[date >= "2020-03-01"]

covid.panel.monthly <- covid.panel.daily[, .(monthly_cases_per1m = sum(daily_cases_per1m), monthly_deaths_per1m = sum(daily_deaths_per1m),
                                             teaching_campus = mean(teaching_campus), teaching_hybrid = mean(teaching_hybrid)),
                                         by = .(fips, classroom, state_name, monthdate)]

# Column (1): OLS, daily cases per million population, with county and date fixed effects, and NO controls

mod.ols.dailycasespop.nocontrols <- summary(feols(daily_cases_per1m ~ teaching_campus + teaching_hybrid
                                                  | fips + date, data = covid.panel.daily), cluster = ~ state_name + date)

# Column (2): OLS, monthly cases per million population, with county and date fixed effects, and NO controls

mod.ols.monthlycasespop.nocontrols <- summary(feols(monthly_cases_per1m ~ teaching_campus + teaching_hybrid
                                                  | fips + monthdate, data = covid.panel.monthly), cluster = ~ state_name + monthdate)

# Column (3): OLS, daily deaths per million population, with county and date fixed effects, and NO controls

mod.ols.dailydeathspop.nocontrols <- summary(feols(daily_deaths_per1m ~ teaching_campus + teaching_hybrid
                                                   | fips + date, data = covid.panel.daily), cluster = ~ state_name + date)

# Column (4): OLS, monthly deaths per million population, with county and date fixed effects, and NO controls

mod.ols.monthlydeathspop.nocontrols <- summary(feols(monthly_deaths_per1m ~ teaching_campus + teaching_hybrid
                                                   | fips + monthdate, data = covid.panel.monthly), cluster = ~ state_name + monthdate)
stats.rows <- huxtable(rbind(
  c("County fixed effects", "Yes", "Yes", "Yes", "Yes"),
  c("Date fixed effects", "Yes", "", "Yes", ""),
  c("Month of sample FE", "", "Yes", "", "Yes")
))

# Form and save regression output table as .tex using huxtable

regtable.covid.monthly <- huxreg(mod.ols.dailycasespop.nocontrols, mod.ols.monthlycasespop.nocontrols, 
                         mod.ols.dailydeathspop.nocontrols, mod.ols.monthlydeathspop.nocontrols,
                         coefs = c("Teaching: Campus" = "teaching_campus", "Teaching: Hybrid" = "teaching_hybrid"),
                         statistics = c("Observations" = "nobs"), note = "", stars = c(`*` = 0.1, `**` = 0.05, `***` = 0.01)) %>%
  insert_row(c("", "New cases per 1m pop.", "", "Deaths per 1m pop.", ""), copy_cell_props = FALSE, after = 0) %>%
  insert_row(c("", "Daily", "Monthly", "Daily", "Monthly"), copy_cell_props = FALSE, after = 1) %>%
  add_rows(stats.rows, after = 7, copy_cell_props = FALSE) %>%
  merge_across(row = 1, col = 2:3) %>% merge_across(row = 1, col = 4:5) %>%
  set_align(col = 1, value = "left") %>% set_align(col = 2:5, value = "center") %>% 
  set_tb_padding(value = 0) %>% set_tb_padding(row = 2, value = 6) %>%
  set_top_padding(row = c(1, 8), value = 4) %>% set_top_padding(row = 4, value = 8) %>%
  set_bottom_padding(row = 11, value = 8) %>%
  set_bottom_padding(row = c(5,7), value = 18) %>%
  set_top_border(row = 1, value = 1) %>% set_bottom_border(row = 1, col = 2:5, value = 0.4) %>%
  set_bottom_border(row = 3, col = 2:5, value = 0.4) %>%
  set_bottom_border(row = 7, col = 2:5, value = 0.4) %>%
  set_number_format(row = 4:7, col = 2:5, value = "%2.2f") %>%
  set_number_format(row =11, value = fmt_pretty())
regtable.covid.monthly
font_size(regtable.covid.monthly) <- 10
sink(file.path(tablesdir, "Regressions_Covid_Monthly.tex"))
print_latex(regtable.covid.monthly, tabular_only = TRUE)
sink()

# Clean workspace

rm(mod.ols.dailycasespop.nocontrols, mod.ols.dailycasespop.controls, mod.ols.dailydeathspop.nocontrols, mod.ols.dailydeathspop.controls,
   stats.rows, county_ct_all, covid.panel, regtable.covid, mean_daily_cases_per1m_schoolyear, mean_daily_deaths_per1m_schoolyear,
   population_campus, population_hybrid, population_remote, population_share_campus, population_share_hybrid,
   agg.dailycasespop.nocontrols, agg.dailycasespop.controls, agg.dailydeathspop.nocontrols, agg.dailydeathspop.controls,
   agg.national.cases, agg.national.deaths)

#### (B4) REGRESSION TABLE FOR EMPLOYMENT OUTCOMES, WITH TWO GROUPS OF HYBRID AND REMOTE -- ONLY STATES WITH ANY CAMPUS COUNTIES ####

# Prepare panel to use for these regressions

employment.panel <- county.panel[date == monthdate & !is.na(employment) & date >= "2020-03-01" & state_any_campus == "Yes"]
employment.panel[, amed_mothers_lfpr := ifelse(mothers_lfpr > median(mothers_lfpr, na.rm = T), 1, 0)]
employment.panel[, amed_poverty_rate := ifelse(poverty_rate > median(poverty_rate, na.rm = T), 1, 0)]
temp.covid.august31 <- county.panel[date == "2020-08-31", .(fips, cumulative_deaths_per1m)]
temp.covid.august31[, county_death_pctl  := frank(cumulative_deaths_per1m) / .N]
temp.covid.august31[, bmed_deaths_pct := ifelse(county_death_pctl < 0.5, 1, 0)]
employment.panel <- merge(employment.panel, temp.covid.august31[, .(fips, bmed_deaths_pct)], by = "fips")
rm(temp.covid.august31)

# Column (1): natural log of employment, with county and month fixed effects, no controls

mod.logemp.nocon <- summary(feols(log(employment) ~ teaching_campus + teaching_hybrid | fips + monthdate, data = employment.panel), 
                            cluster = ~ state_name + monthdate)

# Column (2): employment per thousand population, with county and month fixed effects, no controls

mod.emp.pop.nocon <- summary(feols(employment_per1k ~ teaching_campus + teaching_hybrid | fips + monthdate, data = employment.panel), 
                             cluster = ~ state_name + monthdate)

# Column (3): employment per thousand population, with county and month fixed effects, no controls: counties with above-median 2019 mother LFPR

mod.emp.pop.nocon.amed.lfpr <- summary(feols(employment_per1k ~ teaching_campus + teaching_hybrid | fips + monthdate, data = employment.panel[amed_mothers_lfpr == 1]), 
                                       cluster = ~ state_name + monthdate)

# Column (4): employment per thousand population, with county and month fixed effects, no controls: counties with above-median 2019 poverty rate

mod.emp.pop.nocon.amed.poverty <- summary(feols(employment_per1k ~ teaching_campus + teaching_hybrid | fips + monthdate, data = employment.panel[amed_poverty_rate == 1]), 
                                          cluster = ~ state_name + monthdate)

# Column (5): employment per thousand population, with county and month fixed effects, no controls: counties with BELOW-median COVID-19 deaths through August 31, 2020

mod.emp.pop.nocon.bmed.deaths <- summary(feols(employment_per1k ~ teaching_campus + teaching_hybrid | fips + monthdate, data = employment.panel[bmed_deaths_pct == 1]), 
                                         cluster = ~ state_name + monthdate)

# Statistics for table
mean_log_employment <- sprintf("%3.2f", mean(log(employment.panel$employment)))
mean_employment_per1k <- sprintf("%4.2f", mean(employment.panel$employment_per1k))
mean_employment_per1k_amed_mothers_lfpr <- sprintf("%4.2f", mean(employment.panel[amed_mothers_lfpr == 1]$employment_per1k))
mean_employment_per1k_amed_poverty_rate <- sprintf("%4.2f", mean(employment.panel[amed_poverty_rate == 1]$employment_per1k))
mean_employment_per1k_bmed_deaths_pct <- sprintf("%4.2f", mean(employment.panel[bmed_deaths_pct == 1]$employment_per1k))
county_ct_all <- formatC(length(unique(employment.panel$fips)), big.mark = ",")
county_ct_amed_mothers_lfpr <- formatC(length(unique(employment.panel[amed_mothers_lfpr == 1]$fips)), big.mark = ",")
county_ct_amed_poverty_rate <- formatC(length(unique(employment.panel[amed_poverty_rate == 1]$fips)), big.mark = ",")
county_ct_bmed_deaths_pct <- formatC(length(unique(employment.panel[bmed_deaths_pct == 1]$fips)), big.mark = ",")

stats.rows <- huxtable(rbind(c("Dep. variable mean", mean_log_employment, mean_employment_per1k, mean_employment_per1k_amed_mothers_lfpr,
                               mean_employment_per1k_amed_poverty_rate, mean_employment_per1k_bmed_deaths_pct),
                             c("County fixed effects", "Yes", "Yes", "Yes", "Yes", "Yes"),
                             c("Month fixed effects", "Yes", "Yes", "Yes", "Yes", "Yes"),
                             c("Number of counties", county_ct_all, county_ct_all, county_ct_amed_mothers_lfpr, county_ct_amed_poverty_rate, county_ct_bmed_deaths_pct)
))

# Form and save regression output table as .tex using huxtable

regtable.employment <- huxreg(mod.logemp.nocon, mod.emp.pop.nocon, mod.emp.pop.nocon.amed.lfpr, mod.emp.pop.nocon.amed.poverty, mod.emp.pop.nocon.bmed.deaths, 
                              coefs = c("Teaching: Campus" = "teaching_campus", "Teaching: Hybrid" = "teaching_hybrid"),
                              statistics = c("Observations" = "nobs", "Adj. R-squared" = "adj.r.squared"), note = "", stars = c(`*` = 0.1, `**` = 0.05, `***` = 0.01)) %>%
  insert_row(c("", "Log-Emp.", "Employment per 1k population", "", "", ""), copy_cell_props = FALSE, after = 0) %>%
  merge_across(row = 1, col = 3:6) %>%
  insert_row(c("", "All counties", "All counties", "Abv. median", "Abv. median", "Blw. median"), copy_cell_props = FALSE, after = 1) %>%
  insert_row(c("", "", "", "mother LFPR", "poverty rate", "COVID deaths"), copy_cell_props = FALSE, after = 2) %>%
  insert_row(c("", "", "", "in 2019", "in 2019", "pre-Sep. 2020"), copy_cell_props = FALSE, after = 3) %>%
  add_rows(stats.rows, after = 9, copy_cell_props = FALSE) %>%
  set_align(col = 1, value = "left") %>% set_align(col = 2:6, value = "center") %>% 
  set_tb_padding(value = 0) %>% set_tb_padding(row = 5, value = 6) %>%
  set_top_padding(row = c(1,2,10), value = 4) %>% set_top_padding(row = 6, value = 8) %>%
  set_bottom_padding(row = 1, value = 6) %>% set_bottom_padding(row = 15, value = 8) %>%
  set_bottom_padding(row = c(7,9), value = 18) %>%
  set_top_border(row = 1, value = 1) %>% set_bottom_border(row = 1, col = 3:6, value = 0.4) %>%
  set_number_format(row = 4, value = fmt_pretty(big.mark = "")) %>%
  set_number_format(row = 6:9, col = 2, value = "%1.3f") %>%
  set_number_format(row = 6:9, col = 3:6, value = "%1.2f") %>%   
  set_number_format(row = 14, value = fmt_pretty())
regtable.employment
font_size(regtable.employment) <- 10
sink(file.path(tablesdir, "Regressions_Employment_States_Any_Campus.tex"))
print_latex(regtable.employment, tabular_only = TRUE)
sink()

# Clean workspace

rm(mod.emp.pop.nocon, mod.logemp.nocon, mod.emp.pop.nocon.amed.lfpr, mod.emp.pop.nocon.amed.poverty, mod.emp.pop.nocon.bmed.deaths,
   employment.panel, regtable.employment, mean_employment_per1k, mean_employment_per1k_amed_mothers_lfpr,
   mean_employment_per1k_amed_poverty_rate, mean_employment_per1k_bmed_deaths_pct, mean_log_employment, county_ct_all,
   county_ct_amed_mothers_lfpr, county_ct_amed_poverty_rate, county_ct_bmed_deaths_pct, stats.rows)

#### (X1) ADDITIONAL RESULTS (NOT SAVED AS A TABLE) FOR REGRESSION OF TOTAL CHANGE IN COVID DEATHS PER MILLION POP. BY TEACHING METHOD ####

# Note: this uses one observation per county

aug30 <- county.panel[date == "2020-08-30", .(fips, classroom, cumulative_cases_per1m_start = cumulative_cases_per1m,
                                              cumulative_deaths_per1m_start = cumulative_deaths_per1m)]
may31 <- county.panel[date == "2021-05-31", .(fips, cumulative_cases_per1m_end = cumulative_cases_per1m,
                                              cumulative_deaths_per1m_end = cumulative_deaths_per1m)]

delta.sy <- merge(aug30, may31, by = "fips")
rm(aug30, may31)

delta.sy[, delta_cases := cumulative_cases_per1m_end - cumulative_cases_per1m_start]
delta.sy[, delta_deaths := cumulative_deaths_per1m_end - cumulative_deaths_per1m_start]
delta.sy[, teaching_campus := ifelse(classroom == "Campus", 1, 0)]
delta.sy[, teaching_hybrid := ifelse(classroom == "Hybrid", 1, 0)]
summary(delta.sy)

summary(lm(delta_cases ~ teaching_campus + teaching_hybrid, data = delta.sy))
summary(lm(delta_deaths ~ teaching_campus + teaching_hybrid, data = delta.sy))

#### (X2) SYNTHETIC CONTROL ESTIMATIONS FOR EMPLOYMENT (NOT SAVED AS A TABLE) ####

# Prepare panels to use for these regressions

employment.panel <- county.panel[date == monthdate & !is.na(employment) & date >= "2020-03-01"]

employment.panel <- employment.panel[, .(fips, classroom, state_name, monthdate, teaching_hybrid, teaching_campus, employment_per1k)]

setkey(employment.panel, fips, monthdate)
employment.panel[, idx_monthdate := frank(.I), by = fips]

# Tabulate the number of counties by teaching method 

unique.counties <- unique(employment.panel[, .(fips, classroom)], by = NULL)
table(unique.counties$classroom)

# Keep a random 50 percent subsample of Hybrid counties (for estimation to work)

set.seed(12345) 

unique.counties[, random_num := runif(length(unique.counties$fips))]
est.counties <- unique.counties[classroom %in% c("Campus", "Remote") | random_num <= 0.50]
table(est.counties$classroom)

employment.panel.est.sam <- merge(employment.panel, est.counties[, .(fips)], by = "fips")
table(employment.panel.est.sam$classroom)

# Synthetic control estimates for employment per thousand population: separately for Campus and Hybrid (always using Remote as donor pool)

synth.est.campus.employment <- augsynth(employment_per1k ~ teaching_campus, unit = fips, time = idx_monthdate, 
                                        data = employment.panel.est.sam[classroom %in% c("Campus", "Remote")], progfun = "none", fixedeff = FALSE)

synth.est.hybrid.employment <- augsynth(employment_per1k ~ teaching_hybrid, unit = fips, time = idx_monthdate, 
                                        data = employment.panel.est.sam[classroom %in% c("Hybrid", "Remote")], progfun = "none", fixedeff = FALSE)

# Display results

synth.est.campus.employment
synth.est.hybrid.employment

#### (X3) SYNTHETIC CONTROL ESTIMATIONS FOR COVID-19 CASES AND DEATHS (NOT SAVED AS A TABLE) ####

# Prepare panels to use for these regressions

covid.panel.daily <- county.panel[date >= "2020-03-01"]

covid.panel.monthly <- covid.panel.daily[, .(monthly_cases_per1m = sum(daily_cases_per1m), monthly_deaths_per1m = sum(daily_deaths_per1m),
                                             teaching_campus = min(teaching_campus), teaching_hybrid = min(teaching_hybrid)),
                                         by = .(fips, classroom, state_name, monthdate)]

setkey(covid.panel.monthly, fips, monthdate)
covid.panel.monthly[, idx_monthdate := frank(.I), by = fips]

# Tabulate the number of counties by teaching method 

unique.counties <- unique(covid.panel.monthly[, .(fips, classroom)], by = NULL)
table(unique.counties$classroom)

# Keep a random 50 percent subsample of Hybrid counties (for estimation to work)

set.seed(12345) 

unique.counties[, random_num := runif(length(unique.counties$fips))]
est.counties <- unique.counties[classroom %in% c("Campus", "Remote") | random_num <= 0.50]
table(est.counties$classroom)

covid.panel.monthly.est.sam <- merge(covid.panel.monthly, est.counties[, .(fips)], by = "fips")
table(covid.panel.monthly.est.sam$classroom)

# Synthetic control estimates for COVID-19 cases per million population: separately for Campus and Hybrid (always using Remote as donor pool)

synth.est.campus.cases <- augsynth(monthly_cases_per1m ~ teaching_campus, unit = fips, time = idx_monthdate, 
                                   data = covid.panel.monthly.est.sam[classroom %in% c("Campus", "Remote")], progfun = "none", fixedeff = FALSE)

synth.est.hybrid.cases <- augsynth(monthly_cases_per1m ~ teaching_hybrid, unit = fips, time = idx_monthdate, 
                                   data = covid.panel.monthly.est.sam[classroom %in% c("Hybrid", "Remote")], progfun = "none", fixedeff = FALSE)

# Synthetic control estimates for COVID-19 deaths per million population: separately for Campus and Hybrid (always using Remote as donor pool)

synth.est.campus.deaths <- augsynth(monthly_deaths_per1m ~ teaching_campus, unit = fips, time = idx_monthdate, 
                                    data = covid.panel.monthly.est.sam[classroom %in% c("Campus", "Remote")], progfun = "none", fixedeff = FALSE)

synth.est.hybrid.deaths <- augsynth(monthly_deaths_per1m ~ teaching_hybrid, unit = fips, time = idx_monthdate, 
                                    data = covid.panel.monthly.est.sam[classroom %in% c("Hybrid", "Remote")], progfun = "none", fixedeff = FALSE)

# Display results

synth.est.campus.cases
synth.est.campus.deaths

synth.est.hybrid.cases
synth.est.hybrid.deaths

#### (X4) GOOGLE MOBILITY INDEX FOR WORKPLACES -- DIFFERENCE IN DIFFERENCES ESTIMATES (NOT SAVED AS A TABLE) ####

# Prepare panel to use for these regressions

mobility.panel <- county.panel[date >= "2020-03-01"]

# workplaces mobility, with county and date fixed effects, no controls

summary(feols(moveidx_workplaces ~ teaching_campus + teaching_hybrid | fips + date, 
              data = mobility.panel[missing_moveidx_workplaces == 0]), cluster = ~ state_name + date)

mean(mobility.panel[missing_moveidx_workplaces == 0]$moveidx_workplaces)

#### END ####
